Learn R Programming

SIfEK (version 0.1.0)

Chymo_high: Product concentration of 101 observed time

Description

A synthetic data set of the product concentration of the enzyme kinetics with lower initial enzyme concentration and discrete observed time.

Usage

Chymo_high

Arguments

Format

A data frame with 101 rows and 2 variables